==> whmcs-8.6.2-release.1.zip: modules/addons/project_management/index.php <==
<?php //ICB0 72:0 81:1058                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.6.2 (8.6.2-release.1)                                      *
// * BuildId:b8a9b70.304                                                  *
// * Build Date:14 Jun 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPmMGtsnGVoH3NIDAJyVK+Z2ZOyJRziH5/kyowYR6rRZq9F8aoIcn6oVJfAA/viZRI+UVwNQ8
JYkU6kDqRlub8uId03DoORBtAAVJYTM2bQRD+6WtOYHsVU+jveyW/GhxkaybzizeyYk62LrHkKEc
9KijC2UMg51QJUwLgkQCDlIFvEykRoLKGzvZi/GmzKNvGl0ZdeIlENMNLWxalApi/xAlpK9Prv7q
aNdrCDxvGf0SngYKfNbB5+jSm+LD2dmYcyCmDynSQsFivVP81nOaSjOGwG0cJ8zPcEqMenTZ0a5w
05j7otKBKU2JEUxQDifXOe6lEb/UVFX1CiaBh874gVH7sxLLzvyi4SIDJyAzStepvJhMJky5uD94
hyQ7eMlijN5+sXg1fF8X8B2109lGPbHN+HGEt+gXABfyjefllkDhMsjXSaMV7E02skP6V2Ja3A1G
vtBRLyjeyyasu+NyZxNxFsyG7x1iJRnir30vA2RSn8o1s5y4A2Ong/6I6clWUeJBQ1yLvLtTj7Fl
t09oJNacCOkQ6RptkJl73/owSRrK3O+BIIFXNEOr1cUK2N32sRVQmWa+fWGcxDt93+q6hpZRRgyo
IxPzYyUH1/66ZxixQa/vdx853VLu0uu14AqVu05vx6A5uH8ILo5Lk+ApCRcB9ZxGKWeBtuPoHqU5
7DuVHNSz1EjZ0uiUczTiLoRnhFHYNk61Piy7DAi1Z0diOMcHpd3AdZA8iGZQStb5xtM5Vwdz4Aod
VC22eMIL+r6gB9XyHOSPB0TvahPh3jldZBX1Jtog0xWu6UiAe++j5SkdLeD9NieQP5stX7uPAeGq
qurNOpbXLC+/nBEJEsqGjohEjYxOGwRSB2gMGCDZuADJv7O9GdSw3v38Csy76sPt8TgoNTAp7G===
HR+cPwqshLwW6XQHpOWuVINWI3y7t/F2N3jNyQV8V5rkvUzfpUZ8mfusqb8Q9fj074uXgyri2OQb
/6tgJTmX32a5WZRPNwk/uD6gz4rTVBLSt8g6m0mCcs6hyzXzIXeSrQwvOZ/jvRFZ1dE1B+MAFGqg
Y8KjARBD6Js5RoKRZP1OPIL4hSWSEhEcqMxdSlLfx8eeMP1xM29drwY/ORoy/iQwbN5jNIFJs/pK
6Kg62qXcq6gi7IzbaEUWdxHiEEUlaRhM4GCeUL2DisxqAKNVln5LuDx9u+oXM/VkE7E9gfpMou52
0blESwnvWtoPbP0FVkt8hWup9/+d0msTKZKRvgi/d1UDPbl51S+VrfpuFUd2vn8/8cNuPBzu/ymZ
HmdODiHnGfhvWTYIGHIdGb1QLte/09xNwfTt8qgixWi6QrFyuVDZkddyrHzlZCyoRevKUut0NZTm
KXQbh43DD6NlipZr56ZOqVs87kCr99MczHiBy+XZStxKBWapUtCP0Rgm6oVdL2WeAgAwK4CIrqrq
+bMBhVc4Tvbj6GMRJxOBCK/jUL+sKmBf2Ho86LSIQWV7Dy5CcPWqUKJrLByczpIJnsxsrNlrhB1K
Fg+nykicSG0KiDgDlnhfkv7rXttrol+h6WAZz6csrvOubX0JKztDImEVcjAsHJOvdo1WWTWcf7LW
+jJ8z2byzHHjfv4x79MFTuOGhGT9WHn/3+DtE+WEYKuB6Q8dDkQcg7s5YnH4R54OJJKXesy/3VM8
YkHphpLrPARtRQO+UYcUlvmlDniahkiCuSJdJOKwKQq7QE4816NoPF5FSnfiFIS+BInlblidN1H4
yugl6TlTFrqCzP+44As7TkE/bRYYj15ayt52MF6siAEIl++V7AoBoJc2

==> whmcs-8.10.0-release.1.zip: modules/addons/project_management/index.php <==
<?php //ICB0 72:0 81:1058                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.10.0 (8.10.0-release.1)                                    *
// * BuildId:dc9095d.372                                                  *
// * Build Date:23 Apr 2024                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cP/aAXu84rNkreRaIeKcquFqpoMtt5upB2ep8ePMVOr5TayQcwuFfH/lTjgHG7G16hqIRghj9
AIzMjMN6VIrmu2+VgrNn5aXd59h65UJ5/TuqBWdVjwRE4+zv2hjII7l4Vbf9AdC7iugO6Q+opyu7
pjxA+hNJGrvHqakxSJdHkCCJuRAqGDceva69M+afxXQP/msr6HOolYpowDp+pE/PO9tNOFE6Y2WN
uEThHqCcWaVfvSHDQ3a4VW6/jqDJfFKpCNG20X3mIORP0sJ5ugcsG8VDrmK0PbI3iCDwYuOXe69X
MCabTHxOQd7+Ak4kDaYKcHU/JpwyavCoiC92NYFgnG1BSGMSQdvc/QdWwsaDI6OFgS+9EMQV8BSl
SWHVWDBYGzhjTBXCCWdAKHB5FwIlU3UaCO+gGWLZyAKJ18A+GpFr2X7oZGa+Vr+ZLk6xnnOZE5E2
uTC2GG6G0NVrxEl6dWnN41toZPA2T65puSMtyBB8wyw3A20pG0Wbqkdjv4RBMvfX6qhE7OH+hmF1
7FISpDoycFlezFr8Yp4vMYpn887KItGzsoNBve63W7W4KWegg1Qmt2HC9gV95ukK/VK25GQ0JSdL
OxAxZrW9hhaT5jV7tq4cqNHwmZH1NdY8vqbliCT3o53Qc5xiQ7BaN9lvdDurG1nbVHQUFgly9v7d
k9LOeAEiRWwDRF6al1ztfVKv32a2xHClj1ICS5SXvclRscvSAs7cnudl2vSPorHRaWFYnluuqZZE
vy9fzXG8d+I59Q5vexB//2mZNHxzQOxrlipB+J6mgawvrPVBJB81ICEJOZ1gxZBJ2lK1swDyZZtz
J6dAkcMPFfQqqp9CHUfuKqlIZmDV7iwlrv9kHXrrGWawZOFFRVRs/CQmOJZMLjkXDEwwLzdgYm===
HR+cPmhTsQYLFYAF46DCYrGp3Vlh+MQ7nqpD+UiRp2nWd/u3mzGIPCyJD7OxgZ1jPOC3vWWtfWM2
+IFw/5M530NcAXkPZlEpXcGk5lKWx4hO57/OMrilr5rPMaQvgQQ84JL9Qr1JazogaLXSvl7F3f4A
7RYMI1N6NlC8x1UV6oTsWvO3Z5IZsEQvzX19IfNbOKXHe0K50KzLlmxRhKyu8LDiUPQKO1bY6sCF
hiL6CNf6WCmLM8CLzPEpP9VtQ24HKdU712NoP1rBrCT3hEkJPiD6eB/0vKs5xJN6ZIUYfEgsbI5c
qH8FJGrgZQQEa/NAMNCseEi4MF5gY7kh3ryzSPyK6Ctl3nJMIsXepTcAbsRkcMkKP9SqaKE5onrq
d4KTvLk4h5jPdsIxJ30A4BVULTqLPWB5imfieq3GpvIyt6MD56N1QHCaG2jHkT6E4WFRpvlYHodl
5AdnhH7+vZhc+jXXUVOF05YJ1HIpmxI9o1wrOsbQC1BDKZl/huML82eO1RYAp4rsg6KKFN4k29A/
BrOCe6GeWt34hJKxMaeGyyb8jVOGRcdQl2mm3AhLccXPMshcdowc062rYXHEUghrNmrQRdv8DwP1
URXZ/yNfwLFFAzmBRN6KCUwi6VzGbbc1O6zZ6tWKoFkZcKF66Bwg8yjn7MKkFcUGu+guR12VqMGI
c8sTJtYx0tcpBhFbR2lciSzzTZvpuO2x0ke3C4nT7aSgeehdNEtmMyEAZHU0IA+4xPKc58prqEqD
CuALI+Y7q2V7o7qjG/VBxmEQUv4fO6TKPsQjygFgs3a6WQFwTAE8dPsx04/fGrebc83VH8cPz1PP
4r6TpQPDLSRDsXMlGHQIaiI/vCDv5fKG439TrVT8+SaG1k22IlthMzwBkFyqpBgn
